=============
ESM Autotests
=============



Suite of tests for the esm_tools to see if the tools, models, coupled systems, machines,... still works as expected. Includes reference data.


* Free software: GNU General Public License v2
* Documentation: https://esm-autotests.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
